==> okapi-lib-0.38-sources.jar: net/sf/okapi/lib/xliff2/core/IWithExtElements.java <==
/*===========================================================================
  Copyright (C) 2012-2013 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
===========================================================================*/

package net.sf.okapi.lib.xliff2.core;

/**
 * Provides a common interface to all objects that can have extension elements.
 * @see ExtElements
 * @see ExtElement
 */
public interface IWithExtElements {

	/**
	 * Gets the {@link ExtElements} object associated with this object.
	 * If none exists one is created.
	 * @return the {@link ExtElements} object associated with this object. If none exists one is created.
	 */
	public ExtElements getExtElements ();
	
	/**
	 * Sets the {@link ExtElements} object associated with this object.
	 * @param elements the {@link ExtElements} object associated with this object.
	 * If null, a new {@link ExtElements} object is created.
	 * @return the {@link ExtElements} object associated with this object, never null.
	 */
	public ExtElements setExtElements (ExtElements elements);

	/**
	 * Indicates if there is a {@link ExtElements} object associated with this object.
	 * @return true if there is a {@link ExtElements} object associated with this object,
	 * false otherwise.
	 */
	public boolean hasExtElements ();

}

==> okapi-lib-1.41.0-sources.jar: net/sf/okapi/lib/xliff2/core/IWithExtElements.java <==
/*===========================================================================
  Copyright (C) 2012-2013 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
===========================================================================*/

package net.sf.okapi.lib.xliff2.core;

/**
 * Provides a common interface to all objects that can have extension elements.
 * @see ExtElements
 * @see ExtElement
 */
public interface IWithExtElements {

	/**
	 * Gets the {@link ExtElements} object associated with this object.
	 * If none exists one is created.
	 * @return the {@link ExtElements} object associated with this object. If none exists one is created.
	 */
	ExtElements getExtElements();
	
	/**
	 * Sets the {@link ExtElements} object associated with this object.
	 * @param elements the {@link ExtElements} object associated with this object.
	 * If null, a new {@link ExtElements} object is created.
	 * @return the {@link ExtElements} object associated with this object, never null.
	 */
	ExtElements setExtElements(ExtElements elements);

	/**
	 * Indicates if there is a {@link ExtElements} object associated with this object.
	 * @return true if there is a {@link ExtElements} object associated with this object,
	 * false otherwise.
	 */
	boolean hasExtElements();

}
